@@ -169,7 +169,7 @@ class AthenaClient:
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
-                    queries = query_string.split(';')
+                    queries = list(filter(None, query_string.split(';')))
                     if len(queries) > 1:
                         results = [pd.DataFrame.from_dict(item).style.set_caption(
                             f"""Query results for <i>\"{queries[i]};\"</i>""").hide_index().set_table_styles(TABLE_STYLES) for i, item in
